@@ -6,7 +6,7 @@
 import json
 import logging
 import os
-from typing import Union
+from typing import Optional, Union
 
 from appdirs import user_data_dir
 
@@ -47,12 +47,17 @@ class Indicators:
             if os.path.isfile(path):
                 self.parse_stix2(path)
             else:
-                self.log.error("Path specified with env MVT_STIX2 is not "
-                               "a valid file: %s", path)
+                self.log.error("Path specified with env MVT_STIX2 is not a valid file: %s",
+                               path)
 
-    def _new_collection(self, cid: str = "", name: str = "",
-                        description: str = "", file_name: str = "",
-                        file_path: str = "") -> dict:
+    def _new_collection(
+        self,
+        cid: Optional[str] = None,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
+        file_name: Optional[str] = None,
+        file_path: Optional[str] = None
+    ) -> dict:
         return {
             "id": cid,
             "name": name,
@@ -130,8 +135,7 @@ class Indicators:
                 data = json.load(handle)
             except json.decoder.JSONDecodeError:
                 self.log.critical("Unable to parse STIX2 indicator file. "
-                                  "The file is corrupted or in the wrong "
-                                  "format!")
+                                  "The file is corrupted or in the wrong format!")
                 return
 
         malware = {}
@@ -186,7 +190,7 @@ class Indicators:
         self.ioc_collections.extend(collections)
 
     def load_indicators_files(self, files: list,
-                              load_default: bool = True) -> None:
+                              load_default: Optional[bool] = True) -> None:
         """
         Load a list of indicators files.
         """
@@ -272,9 +276,8 @@ class Indicators:
             if final_url.domain.lower() == ioc["value"]:
                 if orig_url.is_shortened and orig_url.url != final_url.url:
                     self.log.warning("Found a known suspicious domain %s "
-                                     "shortened as %s matching indicators "
-                                     "from \"%s\"", final_url.url, orig_url.url,
-                                     ioc["name"])
+                                     "shortened as %s matching indicators from \"%s\"",
+                                     final_url.url, orig_url.url, ioc["name"])
                 else:
                     self.log.warning("Found a known suspicious domain %s "
                                      "matching indicators from \"%s\"",
@@ -339,8 +342,8 @@ class Indicators:
             if len(proc_name) == 16:
                 if ioc["value"].startswith(proc_name):
                     self.log.warning("Found a truncated known suspicious "
-                                     "process name \"%s\" matching indicators "
-                                     "from \"%s\"", process, ioc["name"])
+                                     "process name \"%s\" matching indicators from \"%s\"",
+                                     process, ioc["name"])
                     return ioc
 
         return None
@@ -377,8 +380,8 @@ class Indicators:
 
         for ioc in self.get_iocs("emails"):
             if email.lower() == ioc["value"].lower():
-                self.log.warning("Found a known suspicious email address \"%s\""
-                                 " matching indicators from \"%s\"",
+                self.log.warning("Found a known suspicious email address \"%s\" "
+                                 "matching indicators from \"%s\"",
                                  email, ioc["name"])
                 return ioc
 
@@ -433,6 +436,27 @@ class Indicators:
 
         return None
 
+    def check_file_path_process(self, file_path: str) -> Union[dict, None]:
+        """Check the provided file path contains a process name from the
+        list of indicators
+
+        :param file_path: File path or file name to check against file
+        indicators
+        :type file_path: str
+        :returns: Indicator details if matched, otherwise None
+
+        """
+        if not file_path:
+            return None
+
+        for ioc in self.get_iocs("processes"):
+            parts = file_path.split("/")
+            if ioc["value"] in parts:
+                self.log.warning("Found known suspicious process name mentioned in file at "
+                                  "path \"%s\" matching indicators from \"%s\"",
+                                  file_path, ioc["name"])
+                return ioc
+
     def check_profile(self, profile_uuid: str) -> Union[dict, None]:
         """Check the provided configuration profile UUID against the list of
         indicators.
@@ -468,8 +492,8 @@ class Indicators:
 
         for ioc in self.get_iocs("files_sha256"):
             if file_hash.lower() == ioc["value"].lower():
-                self.log.warning("Found a known suspicious file with hash "
-                                 "\"%s\" matching indicators from \"%s\"",
+                self.log.warning("Found a known suspicious file with hash \"%s\" "
+                                 "matching indicators from \"%s\"",
                                  file_hash, ioc["name"])
                 return ioc
 
