@@ -22,7 +22,7 @@ def convert_chrometime_to_datetime(timestamp: int) -> int:
     return epoch_start + delta
 
 
-def convert_datetime_to_iso(datetime: datetime.datetime) -> str:
+def convert_datetime_to_iso(date_time: datetime.datetime) -> str:
     """Converts datetime to ISO string.
 
     :param datetime: datetime.
@@ -32,12 +32,14 @@ def convert_datetime_to_iso(datetime: datetime.datetime) -> str:
 
     """
     try:
-        return datetime.strftime("%Y-%m-%d %H:%M:%S.%f")
+        return date_time.strftime("%Y-%m-%d %H:%M:%S.%f")
     except Exception:
         return ""
 
 
-def convert_unix_to_utc_datetime(timestamp: Union[int, float, str]) -> datetime.datetime:
+def convert_unix_to_utc_datetime(
+        timestamp: Union[int, float, str]
+) -> datetime.datetime:
     """Converts a unix epoch timestamp to UTC datetime.
 
     :param timestamp: Epoc timestamp to convert.
@@ -105,8 +107,8 @@ def convert_mactime_to_iso(timestamp: int, from_2001: bool = True):
 
     """
 
-    return convert_datetime_to_iso(convert_mactime_to_datetime(timestamp,
-                                                               from_2001))
+    return convert_datetime_to_iso(
+        convert_mactime_to_datetime(timestamp, from_2001))
 
 
 def check_for_links(text: str) -> list:
