@@ -3,10 +3,9 @@
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
-import datetime
 import os
 
-from mvt.common.utils import convert_timestamp_to_iso
+from mvt.common.utils import convert_unix_to_iso
 
 from ..base import IOSExtraction
 
@@ -39,5 +38,5 @@ class WebkitBase(IOSExtraction):
                 self.results.append({
                     "folder": key,
                     "url": url,
-                    "isodate": convert_timestamp_to_iso(datetime.datetime.utcfromtimestamp(os.stat(found_path).st_mtime)),
+                    "isodate": convert_unix_to_iso(os.stat(found_path).st_mtime),
                 })
