@@ -6,7 +6,7 @@
 import collections
 import logging
 import plistlib
-from typing import Union
+from typing import Optional, Union
 
 from mvt.common.utils import convert_mactime_to_iso
 
@@ -24,10 +24,15 @@ IDSTATUSCACHE_ROOT_PATHS = [
 class IDStatusCache(IOSExtraction):
     """Extracts Apple Authentication information from idstatuscache.plist"""
 
-    def __init__(self, file_path: str = None, target_path: str = None,
-                 results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = logging.getLogger(__name__),
-                 results: list = []) -> None:
+    def __init__(
+        self,
+        file_path: Optional[str] = None,
+        target_path: Optional[str] = None,
+        results_path: Optional[str] = None,
+        fast_mode: Optional[bool] = False,
+        log: logging.Logger = logging.getLogger(__name__),
+        results: Optional[list] = None
+    ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -55,8 +60,7 @@ class IDStatusCache(IOSExtraction):
                     continue
 
             if "\\x00\\x00" in result.get("user", ""):
-                self.log.warning("Found an ID Status Cache entry with "
-                                 "suspicious patterns: %s",
+                self.log.warning("Found an ID Status Cache entry with suspicious patterns: %s",
                                  result.get("user"))
                 self.detected.append(result)
 
@@ -83,7 +87,9 @@ class IDStatusCache(IOSExtraction):
                     "idstatus": id_status,
                 })
 
-        entry_counter = collections.Counter([entry["user"] for entry in id_status_cache_entries])
+        entry_counter = collections.Counter([entry["user"]
+                                                for entry in
+                                                    id_status_cache_entries])
         for entry in id_status_cache_entries:
             # Add total count of occurrences to the status cache entry.
             entry["occurrences"] = entry_counter[entry["user"]]
@@ -97,7 +103,8 @@ class IDStatusCache(IOSExtraction):
                           self.file_path)
             self._extract_idstatuscache_entries(self.file_path)
         elif self.is_fs_dump:
-            for idstatuscache_path in self._get_fs_files_from_patterns(IDSTATUSCACHE_ROOT_PATHS):
+            for idstatuscache_path in self._get_fs_files_from_patterns(
+                    IDSTATUSCACHE_ROOT_PATHS):
                 self.file_path = idstatuscache_path
                 self.log.info("Found IDStatusCache plist at path: %s",
                               self.file_path)
