@@ -5,7 +5,7 @@
 
 import logging
 import plistlib
-from typing import Union
+from typing import Optional, Union
 
 from mvt.common.utils import convert_datetime_to_iso
 
@@ -23,10 +23,15 @@ class OSAnalyticsADDaily(IOSExtraction):
     """Extract network usage information by process,
     from com.apple.osanalytics.addaily.plist"""
 
-    def __init__(self, file_path: str = None, target_path: str = None,
-                 results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = logging.getLogger(__name__),
-                 results: list = []) -> None:
+    def __init__(
+        self,
+        file_path: Optional[str] = None,
+        target_path: Optional[str] = None,
+        results_path: Optional[str] = None,
+        fast_mode: Optional[bool] = False,
+        log: logging.Logger = logging.getLogger(__name__),
+        results: Optional[list] = None
+    ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -71,5 +76,5 @@ class OSAnalyticsADDaily(IOSExtraction):
                 "wwan_out": values[4],
             })
 
-        self.log.info("Extracted a total of %d com.apple.osanalytics.addaily "
-                      "entries", len(self.results))
+        self.log.info("Extracted a total of %d com.apple.osanalytics.addaily entries",
+                      len(self.results))
