@@ -6,7 +6,7 @@
 import logging
 import sqlite3
 from base64 import b64encode
-from typing import Union
+from typing import Optional, Union
 
 from mvt.common.utils import check_for_links, convert_mactime_to_iso
 
@@ -23,10 +23,15 @@ SMS_ROOT_PATHS = [
 class SMS(IOSExtraction):
     """This module extracts all SMS messages containing links."""
 
-    def __init__(self, file_path: str = None, target_path: str = None,
-                 results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = logging.getLogger(__name__),
-                 results: list = []) -> None:
+    def __init__(
+        self,
+        file_path: Optional[str] = None,
+        target_path: Optional[str] = None,
+        results_path: Optional[str] = None,
+        fast_mode: Optional[bool] = False,
+        log: logging.Logger = logging.getLogger(__name__),
+        results: Optional[list] = None
+    ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -92,7 +97,8 @@ class SMS(IOSExtraction):
             for index, value in enumerate(item):
                 # We base64 escape some of the attributes that could contain
                 # binary data.
-                if (names[index] == "attributedBody" or names[index] == "payload_data"
+                if (names[index] == "attributedBody"
+                        or names[index] == "payload_data"
                         or names[index] == "message_summary_info") and value:
                     value = b64encode(value).decode()
 
@@ -108,9 +114,10 @@ class SMS(IOSExtraction):
             if not message.get("text", None):
                 message["text"] = ""
 
-            if message.get("text", "").startswith("ALERT: State-sponsored attackers may be targeting your iPhone"):
-                self.log.warn("Apple warning about state-sponsored attack "
-                              "received on the %s", message["isodate"])
+            alert = "ALERT: State-sponsored attackers may be targeting your iPhone"
+            if message.get("text", "").startswith(alert):
+                self.log.warning("Apple warning about state-sponsored attack received on the %s",
+                                 message["isodate"])
                 self.results.append(message)
             else:
                 # Extract links from the SMS message.
