@@ -6,6 +6,7 @@
 import logging
 import os
 import plistlib
+from typing import Optional
 
 from mvt.common.utils import convert_datetime_to_iso
 
@@ -14,11 +15,11 @@ from ..base import IOSExtraction
 WEBKIT_SESSION_RESOURCE_LOG_BACKUP_IDS = [
     "a500ee38053454a02e990957be8a251935e28d3f",
 ]
-WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH = "Library/WebKit/WebsiteData/ResourceLoadStatistics/full_browsing_session_resourceLog.plist"
+WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH = "Library/WebKit/WebsiteData/ResourceLoadStatistics/full_browsing_session_resourceLog.plist"  # pylint: disable=line-too-long
 WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS = [
-    "private/var/mobile/Containers/Data/Application/*/SystemData/com.apple.SafariViewService/Library/WebKit/WebsiteData/full_browsing_session_resourceLog.plist",
-    "private/var/mobile/Containers/Data/Application/*/Library/WebKit/WebsiteData/ResourceLoadStatistics/full_browsing_session_resourceLog.plist",
-    "private/var/mobile/Library/WebClips/*/Storage/full_browsing_session_resourceLog.plist",
+    "private/var/mobile/Containers/Data/Application/*/SystemData/com.apple.SafariViewService/Library/WebKit/WebsiteData/full_browsing_session_resourceLog.plist",  # pylint: disable=line-too-long
+    "private/var/mobile/Containers/Data/Application/*/Library/WebKit/WebsiteData/ResourceLoadStatistics/full_browsing_session_resourceLog.plist",  # pylint: disable=line-too-long
+    "private/var/mobile/Library/WebClips/*/Storage/full_browsing_session_resourceLog.plist",  # pylint: disable=line-too-long
 ]
 
 
@@ -30,10 +31,15 @@ class WebkitSessionResourceLog(IOSExtraction):
 
     """
 
-    def __init__(self, file_path: str = None, target_path: str = None,
-                 results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = logging.getLogger(__name__),
-                 results: list = []) -> None:
+    def __init__(
+        self,
+        file_path: Optional[str] = None,
+        target_path: Optional[str] = None,
+        results_path: Optional[str] = None,
+        fast_mode: Optional[bool] = False,
+        log: logging.Logger = logging.getLogger(__name__),
+        results: Optional[list] = None
+    ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -61,13 +67,20 @@ class WebkitSessionResourceLog(IOSExtraction):
         for _, entries in self.results.items():
             for entry in entries:
                 source_domains = self._extract_domains(entry["redirect_source"])
-                destination_domains = self._extract_domains(entry["redirect_destination"])
+                destination_domains = self._extract_domains(
+                    entry["redirect_destination"])
 
                 # TODO: Currently not used.
-                # subframe_origins = self._extract_domains(entry["subframe_under_origin"])
-                # subresource_domains = self._extract_domains(entry["subresource_under_origin"])
+                # subframe_origins = self._extract_domains(
+                #    entry["subframe_under_origin"])
+                # subresource_domains = self._extract_domains(
+                #    entry["subresource_under_origin"])
 
-                all_origins = set([entry["origin"]] + source_domains + destination_domains)
+                all_origins = set(
+                    [entry["origin"]]
+                    + source_domains
+                    + destination_domains
+                )
 
                 ioc = self.indicators.check_domains(all_origins)
                 if ioc:
@@ -93,8 +106,8 @@ class WebkitSessionResourceLog(IOSExtraction):
 
                         redirect_path += ", ".join(destination_domains)
 
-                    self.log.warning("Found HTTP redirect between suspicious "
-                                     "domains: %s", redirect_path)
+                    self.log.warning("Found HTTP redirect between suspicious domains: %s",
+                                     redirect_path)
 
     def _extract_browsing_stats(self, log_path):
         items = []
@@ -115,7 +128,8 @@ class WebkitSessionResourceLog(IOSExtraction):
                 "subframe_under_origin": item.get("subframeUnderTopFrameOrigins", ""),
                 "subresource_under_origin": item.get("subresourceUnderTopFrameOrigins", ""),
                 "user_interaction": item.get("hadUserInteraction"),
-                "most_recent_interaction": convert_datetime_to_iso(item["mostRecentUserInteraction"]),
+                "most_recent_interaction": convert_datetime_to_iso(
+                    item["mostRecentUserInteraction"]),
                 "last_seen": convert_datetime_to_iso(item["lastSeen"]),
             })
 
@@ -123,20 +137,23 @@ class WebkitSessionResourceLog(IOSExtraction):
 
     def run(self) -> None:
         if self.is_backup:
-            for log_file in self._get_backup_files_from_manifest(relative_path=WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH):
+            for log_file in self._get_backup_files_from_manifest(
+                    relative_path=WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH):
                 log_path = self._get_backup_file_from_id(log_file["file_id"])
+
                 if not log_path:
                     continue
 
-                self.log.info("Found Safari browsing session resource log at "
-                              "path: %s", log_path)
+                self.log.info("Found Safari browsing session resource log at path: %s",
+                              log_path)
                 self.results[log_path] = self._extract_browsing_stats(log_path)
         elif self.is_fs_dump:
-            for log_path in self._get_fs_files_from_patterns(WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS):
-                self.log.info("Found Safari browsing session resource log at "
-                              "path: %s", log_path)
+            for log_path in self._get_fs_files_from_patterns(
+                    WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS):
+                self.log.info("Found Safari browsing session resource log at path: %s",
+                              log_path)
                 key = os.path.relpath(log_path, self.target_path)
                 self.results[key] = self._extract_browsing_stats(log_path)
 
-        self.log.info("Extracted records from %d Safari browsing session "
-                      "resource logs", len(self.results))
+        self.log.info("Extracted records from %d Safari browsing session resource logs",
+                      len(self.results))
