@@ -42,6 +42,9 @@ IPHONE_MODELS = [
     {"identifier": "iPhone14,5", "description": "iPhone 13"},
     {"identifier": "iPhone14,2", "description": "iPhone 13 Pro"},
     {"identifier": "iPhone14,3", "description": "iPhone 13 Pro Max"},
+    {"identifier": "iPhone14,8", "decription": "iPhone 14 Plus"},
+    {"identifier": "iPhone15,2", "description": "iPhone 14 Pro"},
+    {"identifier": "iPhone15,3", "description": "iPhone 14 Pro Max"}
 ]
 
 IPHONE_IOS_VERSIONS = [
@@ -243,6 +246,10 @@ IPHONE_IOS_VERSIONS = [
     {"build": "19F77", "version": "15.5"},
     {"build": "19G71", "version": "15.6"},
     {"build": "19G82", "version": "15.6.1"},
+    {"build": "19H12", "version": "15.7"},
+    {"build": "20A362", "version": "16.0"},
+    {"build": "20B82", "version": "16.1"},
+    {"build": "20B101", "version": "16.1.1"}
 ]
 
 
